@@ -116,6 +116,8 @@
 ( cd opt/kde/share/doc/HTML/da/ksame ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksirc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksirc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/ktnef ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksysv ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ktron ; rm -rf common )
@@ -140,6 +142,8 @@
 ( cd opt/kde/share/doc/HTML/da/kmousetool ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kompare ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kontact ; rm -rf common )
@@ -172,6 +176,8 @@
 ( cd opt/kde/share/doc/HTML/da/konquest ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kturtle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kverbos ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kwallet ; rm -rf common )
@@ -394,6 +400,8 @@
 ( cd opt/kde/share/doc/HTML/da/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/artsbuilder ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konq-plugins ; rm -rf common )
@@ -420,6 +428,8 @@
 ( cd opt/kde/share/doc/HTML/da/kdevelop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kicker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/klatin ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/klines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmines ; rm -rf common )
@@ -474,8 +484,12 @@
 ( cd opt/kde/share/doc/HTML/da/quanta ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kuickshow ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kde_app_devel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kommander ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kiconedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/klettres ; rm -rf common )
@@ -488,12 +502,16 @@
 ( cd opt/kde/share/doc/HTML/da/klickety ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kleopatra ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kenolaba ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kgpgcertmanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kworldclock ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/KRegExpEditor ; rm -rf common )
@@ -546,6 +564,8 @@
 ( cd opt/kde/share/doc/HTML/da/umbrello ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/konqueror ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/korganizer ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/atlantik ; rm -rf common )
